@@ -29,7 +29,9 @@ simulate_data <- function(.tdy_dag, b.default = NULL, b.lower = -0.6, b.upper =
                           N = 500, standardized = TRUE) {
   if_not_tidy_daggity(.tdy_dag) %>%
     .$dag %>%
-    dagitty::simulateSEM(b.default = b.default, b.lower = b.lower, b.upper = b.upper, eps = eps,
-                         N = N, standardized = standardized) %>%
+    dagitty::simulateSEM(
+      b.default = b.default, b.lower = b.lower, b.upper = b.upper, eps = eps,
+      N = N, standardized = standardized
+    ) %>%
     dplyr::as_tibble()
 }
